@@ -433,6 +433,7 @@ class BalancerEntry(
         lb_arn: builtins.str,
         ssl_enabled: builtins.bool,
         target_group_arn: builtins.str,
+        zone_name: builtins.str,
     ) -> None:
         '''
         :param scope: -
@@ -442,6 +443,7 @@ class BalancerEntry(
         :param lb_arn: 
         :param ssl_enabled: 
         :param target_group_arn: 
+        :param zone_name: 
         '''
         props = LoadBalancerProps(
             app_name=app_name,
@@ -449,6 +451,7 @@ class BalancerEntry(
             lb_arn=lb_arn,
             ssl_enabled=ssl_enabled,
             target_group_arn=target_group_arn,
+            zone_name=zone_name,
         )
 
         jsii.create(self.__class__, self, [scope, id, props])
@@ -1214,6 +1217,7 @@ class InternalVPC:
         "lb_arn": "lbArn",
         "ssl_enabled": "sslEnabled",
         "target_group_arn": "targetGroupArn",
+        "zone_name": "zoneName",
     },
 )
 class LoadBalancerProps:
@@ -1225,6 +1229,7 @@ class LoadBalancerProps:
         lb_arn: builtins.str,
         ssl_enabled: builtins.bool,
         target_group_arn: builtins.str,
+        zone_name: builtins.str,
     ) -> None:
         '''
         :param app_name: 
@@ -1232,6 +1237,7 @@ class LoadBalancerProps:
         :param lb_arn: 
         :param ssl_enabled: 
         :param target_group_arn: 
+        :param zone_name: 
         '''
         self._values: typing.Dict[str, typing.Any] = {
             "app_name": app_name,
@@ -1239,6 +1245,7 @@ class LoadBalancerProps:
             "lb_arn": lb_arn,
             "ssl_enabled": ssl_enabled,
             "target_group_arn": target_group_arn,
+            "zone_name": zone_name,
         }
 
     @builtins.property
@@ -1271,6 +1278,12 @@ class LoadBalancerProps:
         assert result is not None, "Required property 'target_group_arn' is missing"
         return typing.cast(builtins.str, result)
 
+    @builtins.property
+    def zone_name(self) -> builtins.str:
+        result = self._values.get("zone_name")
+        assert result is not None, "Required property 'zone_name' is missing"
+        return typing.cast(builtins.str, result)
+
     def __eq__(self, rhs: typing.Any) -> builtins.bool:
         return isinstance(rhs, self.__class__) and rhs._values == self._values
 
@@ -1293,13 +1306,13 @@ class MicroService(
         scope: constructs.Construct,
         id: builtins.str,
         *,
+        ami: builtins.str,
         app_name: builtins.str,
         env: builtins.str,
         role: InternalRole,
         ssh_key: builtins.str,
         subnets: typing.Sequence[builtins.str],
         vpc: builtins.str,
-        ami: typing.Optional[builtins.str] = None,
         application_type: typing.Optional[builtins.str] = None,
         asg_max_size: typing.Optional[builtins.str] = None,
         asg_min_size: typing.Optional[builtins.str] = None,
@@ -1316,13 +1329,13 @@ class MicroService(
         '''
         :param scope: -
         :param id: -
+        :param ami: 
         :param app_name: 
         :param env: 
         :param role: 
         :param ssh_key: 
         :param subnets: 
         :param vpc: 
-        :param ami: 
         :param application_type: 
         :param asg_max_size: 
         :param asg_min_size: 
@@ -1337,13 +1350,13 @@ class MicroService(
         :param tcp_rules: 
         '''
         props = MicroServiceProps(
+            ami=ami,
             app_name=app_name,
             env=env,
             role=role,
             ssh_key=ssh_key,
             subnets=subnets,
             vpc=vpc,
-            ami=ami,
             application_type=application_type,
             asg_max_size=asg_max_size,
             asg_min_size=asg_min_size,
@@ -1462,13 +1475,13 @@ class MicroService(
     jsii_type="@smallcase/aws-cdk-microservice.MicroServiceProps",
     jsii_struct_bases=[],
     name_mapping={
+        "ami": "ami",
         "app_name": "appName",
         "env": "env",
         "role": "role",
         "ssh_key": "sshKey",
         "subnets": "subnets",
         "vpc": "vpc",
-        "ami": "ami",
         "application_type": "applicationType",
         "asg_max_size": "asgMaxSize",
         "asg_min_size": "asgMinSize",
@@ -1487,13 +1500,13 @@ class MicroServiceProps:
     def __init__(
         self,
         *,
+        ami: builtins.str,
         app_name: builtins.str,
         env: builtins.str,
         role: InternalRole,
         ssh_key: builtins.str,
         subnets: typing.Sequence[builtins.str],
         vpc: builtins.str,
-        ami: typing.Optional[builtins.str] = None,
         application_type: typing.Optional[builtins.str] = None,
         asg_max_size: typing.Optional[builtins.str] = None,
         asg_min_size: typing.Optional[builtins.str] = None,
@@ -1508,13 +1521,13 @@ class MicroServiceProps:
         tcp_rules: typing.Optional[typing.Sequence[IngressRule]] = None,
     ) -> None:
         '''
+        :param ami: 
         :param app_name: 
         :param env: 
         :param role: 
         :param ssh_key: 
         :param subnets: 
         :param vpc: 
-        :param ami: 
         :param application_type: 
         :param asg_max_size: 
         :param asg_min_size: 
@@ -1533,6 +1546,7 @@ class MicroServiceProps:
         if isinstance(security_group_props, dict):
             security_group_props = InternalSG(**security_group_props)
         self._values: typing.Dict[str, typing.Any] = {
+            "ami": ami,
             "app_name": app_name,
             "env": env,
             "role": role,
@@ -1540,8 +1554,6 @@ class MicroServiceProps:
             "subnets": subnets,
             "vpc": vpc,
         }
-        if ami is not None:
-            self._values["ami"] = ami
         if application_type is not None:
             self._values["application_type"] = application_type
         if asg_max_size is not None:
@@ -1567,6 +1579,12 @@ class MicroServiceProps:
         if tcp_rules is not None:
             self._values["tcp_rules"] = tcp_rules
 
+    @builtins.property
+    def ami(self) -> builtins.str:
+        result = self._values.get("ami")
+        assert result is not None, "Required property 'ami' is missing"
+        return typing.cast(builtins.str, result)
+
     @builtins.property
     def app_name(self) -> builtins.str:
         result = self._values.get("app_name")
@@ -1603,11 +1621,6 @@ class MicroServiceProps:
         assert result is not None, "Required property 'vpc' is missing"
         return typing.cast(builtins.str, result)
 
-    @builtins.property
-    def ami(self) -> typing.Optional[builtins.str]:
-        result = self._values.get("ami")
-        return typing.cast(typing.Optional[builtins.str], result)
-
     @builtins.property
     def application_type(self) -> typing.Optional[builtins.str]:
         result = self._values.get("application_type")
@@ -1692,6 +1705,7 @@ class MicroServiceProps:
         "port": "port",
         "protocol": "protocol",
         "ssl_enabled": "sslEnabled",
+        "zone_name": "zoneName",
     },
 )
 class NetworkProps:
@@ -1704,6 +1718,7 @@ class NetworkProps:
         port: jsii.Number,
         protocol: builtins.str,
         ssl_enabled: builtins.bool,
+        zone_name: builtins.str,
     ) -> None:
         '''
         :param health_check_path: 
@@ -1712,6 +1727,7 @@ class NetworkProps:
         :param port: 
         :param protocol: 
         :param ssl_enabled: 
+        :param zone_name: 
         '''
         self._values: typing.Dict[str, typing.Any] = {
             "health_check_path": health_check_path,
@@ -1720,6 +1736,7 @@ class NetworkProps:
             "port": port,
             "protocol": protocol,
             "ssl_enabled": ssl_enabled,
+            "zone_name": zone_name,
         }
 
     @builtins.property
@@ -1758,6 +1775,12 @@ class NetworkProps:
         assert result is not None, "Required property 'ssl_enabled' is missing"
         return typing.cast(builtins.bool, result)
 
+    @builtins.property
+    def zone_name(self) -> builtins.str:
+        result = self._values.get("zone_name")
+        assert result is not None, "Required property 'zone_name' is missing"
+        return typing.cast(builtins.str, result)
+
     def __eq__(self, rhs: typing.Any) -> builtins.bool:
         return isinstance(rhs, self.__class__) and rhs._values == self._values
 
